FUNCTION model_bananafunction(par,tau,lamda_A,dlamda_A,nvals,sigT)
!   Function to solve for lamda_B and obtain total stress data
!   for a two network ogden model
!   
!   par - seed parameters
!   tau - sampling rate
!   lamda_A - stretch of network A
!   dlamda_A - derivative of stretch of network A
!   nvals - number of samples of lamda_A and dlamda_A
!   sigT - output variable to store the stress data
!
!   returns total stress in network A and network B 
!!!!!!!!!!!!!!!!!!!
!
!   Anil Palaparthi 04-05-2010
!

!   Data dictionary: declare calling parameter types
    IMPLICIT NONE
    INTEGER, INTENT(IN) :: nvals
    INTEGER :: model_bananafunction
    REAL, INTENT(IN) :: par(6)
    REAL, INTENT(IN) :: tau
    REAL, INTENT(IN) :: lamda_A(nvals)
    REAL, INTENT(IN) :: dlamda_A(nvals)
    REAL, INTENT(OUT) :: sigT(nvals)
    
!   Declaration of variables for Runge-kutta routine
    REAL :: phi,yo,time,temp(6)
    REAL :: RKfor,t
    INTEGER :: tmp,N,c1,c3,c4,Istat,m,k
    
!   Initialize the internal variables for seed parameters
    REAL :: lamda_B = 1., dlamda_B                      ! stretch and its derivative in network B
    REAL :: Z,c,m_B,mu_A, mu_B,a                        ! Internal variables for parameters of ogden model
    Z = par(1)
    c = par(2)
    m_B = par(3)
    mu_A = par(4)
    mu_B = par(5)
    a = par(6)
    

    
!   Initial value for derivative of lamda_B
    dlamda_B = (dlamda_A(1)*(lamda_B/lamda_A(1)))- &
        (2./3.)*lamda_B*Z*((lamda_B-1+1e-15)/abs(lamda_B-1+1e-15))* &
        ((sqrt((1./3.)*((lamda_A(1)/lamda_B)**2 + (2*lamda_B/lamda_A(1))))-1+1e-4)**c)* &
        (abs((2*mu_B/a)*((lamda_B**a) - (lamda_B**(-0.5*a)))))**m_B

!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!        
!   Initialization for RKfor.m DO NOT CHANGE ANYTHING
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
    phi = lamda_B                               ! RK routine internal variable
    yo  = phi                                   ! RK routine internal variable
    N   = 1                                     ! Number of equations to be solved by RK4
    tmp = 1                                     ! Temporary counting array
    c1  = tmp+1                                 ! Indecies for regaining
    c3  = tmp+1+2*N                             ! _above variables
    c4  = tmp+1+3*N                             ! _from RK4 output
    time = 0.                                   ! Time set to zero
    sigT = 0.                                   ! Initialize total stress    
    sigT(1) = (2*mu_A/a)*((lamda_A(1))**(a-1) - (lamda_A(1))**(-0.5*a-1))+ &
        (2*mu_B/a)*((lamda_B)**(a-1) - (lamda_B)**(-0.5*a-1))
        
    DO k = 2,nvals
        Istat = 1
        m = 0
        DO WHILE (Istat /= 0)
            m = m+1
            t = RKfor(N,lamda_B,dlamda_B,time,tau,phi,yo,m,temp)
            
            Istat = INT(temp(1))                ! Condition of loop
            lamda_B = temp(c1)                  ! Update the RKA variables    
            phi = temp(c3)                      ! Internal variable to recall
            yo = temp(c4)                       ! Internal variable to recall
            time = temp(6)                      ! Time update   
            
!           derivative of lamda_B
            dlamda_B = (dlamda_A(k)*(lamda_B/lamda_A(k-1)))- &
                (2./3.)*lamda_B*Z*((lamda_B-1+1e-15)/abs(lamda_B-1+1e-15))* &
                ((sqrt((1./3.)*((lamda_A(k-1)/lamda_B)**2 + (2*lamda_B/lamda_A(k-1))))-1+1e-4)**c)* &
                (abs((2*mu_B/a)*((lamda_B**a) - (lamda_B**(-0.5*a)))))**m_B 
        END DO
!       Stress
        sigT(k) = (2*mu_A/a)*((lamda_A(k))**(a-1) - (lamda_A(k))**(-0.5*a-1))+ &
            (2*mu_B/a)*((lamda_B)**(a-1) - (lamda_B)**(-0.5*a-1))
    END DO
    model_bananafunction = 1                    ! return value for the function    
END FUNCTION model_bananafunction